.. _contrib:

Huey Extensions
===============

The ``huey.contrib`` package contains modules that provide extra functionality
beyond the core APIs.


.. include:: sqlite.rst


.. include:: django.rst
